#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var express = require("express");
var http = require("http");
var path_1 = require("path");
var chalk = require('chalk');
var server_1 = require("../core/portal/server");
var engine_1 = require("../core/engine");
var remoteMethods_1 = require("./remoteMethods");
var relay_1 = require("./relay");
var defaultConfig20_1 = require("../core/engine/config/defaultConfig20");
var app = express();
app.use(express.static(path_1.join(__dirname, '../../build')));
var server = http.createServer(app);
var projectPath = process.argv[2] || process.cwd();
var engine = new engine_1.default(projectPath, defaultConfig20_1.default(projectPath));
engine.testFiles.read(engine.root);
var port = process.env.PORT || 3005;
server.listen(port, function (err) {
    if (err) {
        console.log(err);
    }
    engine.getVersion().then(function (version) {
        console.log("\n     " + chalk.black.bgYellow.bold(" Majestic v" + version + " ") + "\n  " + chalk.white('Zero config UI for Jest') + "\n\nvisit " + chalk.green("http://localhost:" + port) + "\n    ");
    });
});
server_1.bootstrap(server).then(function () {
    server_1.register('ui', remoteMethods_1.default(engine), function (remote) {
        engine.watcher.handlers(function (path) {
            remote.onFileAdd(path, engine.testFiles.read(engine.root));
        }, function (path) {
            remote.onFileDelete(path, engine.testFiles.read(engine.root));
        }, function (path, itBlocks) {
            if (itBlocks) {
                remote.onFileChange(path, itBlocks);
            }
        });
        engine.testRunner.registerOnDebuggerExit(function () {
            remote.onDebuggerExit();
        });
    });
});
relay_1.getConnection();
process.on('exit', function () {
    console.log('Killing the runner before exit');
    engine.testRunner.kill();
});
//# sourceMappingURL=index.js.map